grib2io.tables.section4_discipline4 API documentation

# grib2io.tables.section4_discipline4

View Source

    table_4_2_4_0  = {
    '0':['Temperature','K','TMPSWP'],
    '1':['Electron Temperature','K','ELECTMP'],
    '2':['Proton Temperature','K','PROTTMP'],
    '3':['Ion Temperature','K','IONTMP'],
    '4':['Parallel Temperature','K','PRATMP'],
    '5':['Perpendicular Temperature','K','PRPTMP'],
    '6-191':['Reserved','unknown','unknown'],
    '192-254':['Reserved for Local Use','unknown','unknown'],
    '255':['Missing','unknown','unknown'],
    }
    table_4_2_4_1  = {
    '0':['Velocity Magnitude (Speed)','m s-1','SPEED'],
    '1':['1st Vector Component of Velocity  (Coordinate system dependent)','m s-1','VEL1'],
    '2':['2nd Vector Component of Velocity  (Coordinate system dependent)','m s-1','VEL2'],
    '3':['3rd Vector Component of Velocity  (Coordinate system dependent)','m s-1','VEL3'],
    '4-191':['Reserved','unknown','unknown'],
    '192-254':['Reserved for Local Use','unknown','unknown'],
    '255':['Missing','unknown','unknown'],
    }
    table_4_2_4_2  = {
    '0':['Particle Number Density','m-3','PLSMDEN'],
    '1':['Electron Density','m-3','ELCDEN'],
    '2':['Proton Density','m-3','PROTDEN'],
    '3':['Ion Density','m-3','IONDEN'],
    '4':['Vertical Electron Content','m-2','VTEC'],
    '5':['HF Absorption Frequency','Hz','ABSFRQ'],
    '6':['HF Absorption','dB','ABSRB'],
    '7':['Spread F','m','SPRDF'],
    '8':['hF','m','HPRIMF'],
    '9':['Critical Frequency','Hz','CRTFRQ'],
    '10':['Scintillation','Numeric','SCINT'],
    '11-191':['Reserved','unknown','unknown'],
    '192-254':['Reserved for Local Use','unknown','unknown'],
    '255':['Missing','unknown','unknown'],
    }
    table_4_2_4_3  = {
    '0':['Magnetic Field Magnitude','T','BTOT'],
    '1':['1st Vector Component of Magnetic Field','T','BVEC1'],
    '2':['2nd Vector Component of Magnetic Field','T','BVEC2'],
    '3':['3rd Vector Component of Magnetic Field','T','BVEC3'],
    '4':['Electric Field Magnitude','V m-1','ETOT'],
    '5':['1st Vector Component of Electric Field','V m-1','EVEC1'],
    '6':['2nd Vector Component of Electric Field','V m-1','EVEC2'],
    '7':['3rd Vector Component of Electric Field','V m-1','EVEC3'],
    '8-191':['Reserved','unknown','unknown'],
    '192-254':['Reserved for Local Use','unknown','unknown'],
    '255':['Missing','unknown','unknown'],
    }
    table_4_2_4_4  = {
    '0':['Proton Flux (Differential)','(m2 s sr eV)-1','DIFPFLUX'],
    '1':['Proton Flux (Integral)','(m2 s sr)-1','INTPFLUX'],
    '2':['Electron Flux (Differential)','(m2 s sr eV)-1','DIFEFLUX'],
    '3':['Electron Flux (Integral)','(m2 s sr)-1','INTEFLUX'],
    '4':['Heavy Ion Flux (Differential)','(m2 s sr eV / nuc)-1','DIFIFLUX'],
    '5':['Heavy Ion Flux (iIntegral)','(m2 s sr)-1','INTIFLUX'],
    '6':['Cosmic Ray Neutron Flux','h-1','NTRNFLUX'],
    '7-191':['Reserved','unknown','unknown'],
    '192-254':['Reserved for Local Use','unknown','unknown'],
    '255':['Missing','unknown','unknown'],
    }
    table_4_2_4_5  = {
    '0-191':['Reserved','unknown','unknown'],
    '192-254':['Reserved for Local Use','unknown','unknown'],
    '255':['Missing','unknown','unknown'],
    }
    table_4_2_4_6  = {
    '0':['Integrated Solar Irradiance','W m-2','TSI'],
    '1':['Solar X-ray Flux (XRS Long)','W m-2','XLONG'],
    '2':['Solar X-ray Flux (XRS Short)','W m-2','XSHRT'],
    '3':['Solar EUV Irradiance','W m-2','EUVIRR'],
    '4':['Solar Spectral Irradiance','W m-2 nm-1','SPECIRR'],
    '5':['F10.7','W m-2 Hz-1','F107'],
    '6':['Solar Radio Emissions','W m-2 Hz-1','SOLRF'],
    '7-191':['Reserved','unknown','unknown'],
    '192-254':['Reserved for Local Use','unknown','unknown'],
    '255':['Missing','unknown','unknown'],
    }
    table_4_2_4_7  = {
    '0':['Limb Intensity','m-2 s-1','LMBINT'],
    '1':['Disk Intensity','m-2 s-1','DSKINT'],
    '2':['Disk Intensity Day','m-2 s-1','DSKDAY'],
    '3':['Disk Intensity Night','m-2 s-1','DSKNGT'],
    '4-191':['Reserved','unknown','unknown'],
    '192-254':['Reserved for Local Use','unknown','unknown'],
    '255':['Missing','unknown','unknown'],
    }
    table_4_2_4_8  = {
    '0':['X-Ray Radiance','W sr-1 m-2','XRAYRAD'],
    '1':['EUV Radiance','W sr-1 m-2','EUVRAD'],
    '2':['H-Alpha Radiance','W sr-1 m-2','HARAD'],
    '3':['White Light Radiance','W sr-1 m-2','WHTRAD'],
    '4':['CaII-K Radiance','W sr-1 m-2','CAIIRAD'],
    '5':['White Light Coronagraph Radiance','W sr-1 m-2','WHTCOR'],
    '6':['Heliospheric Radiance','W sr-1 m-2','HELCOR'],
    '7':['Thematic Mask','Numeric','MASK'],
    '8-191':['Reserved','unknown','unknown'],
    '192-254':['Reserved for Local Use','unknown','unknown'],
    '255':['Missing','unknown','unknown'],
    }
    table_4_2_4_9  = {
    '0':['Pedersen Conductivity','S m-1','SIGPED'],
    '1':['Hall Conductivity','S m-1','SIGHAL'],
    '2':['Parallel Conductivity','S m-1','SIGPAR'],
    '3-191':['Reserved','unknown','unknown'],
    '192-254':['Reserved for Local Use','unknown','unknown'],
    '255':['Missing','unknown','unknown'],
    }